::cisco::eem::event_register_none maxrun 180

# David Lin (dalin@cisco.com)
#
# May 13, 2009
#
# IGMPv2/v3 Static Join Configuration Tool
#
# Example of what this script will configure under an interface:
#
#         interface vlan 90
# 	     ip igmp static-group x.x.x.x source x.x.x.x
#            ip igmp version [2|3]
#
# -----------
# Assumptions 
# -----------
#        'ip pim sparse-mode' is configured under all interfaces
#        'ip pim ssm default' is configured globally
#
# ------
# Envars 
# ------
#        ------------------------------------------------------------------------------------
#        Name	 		Description
#        ------------------------------------------------------------------------------------
#	 igmp_version	        IGMP version, 2 or 3
#        igmp_interface         interface to apply static joins
#        igmp_add_remove        'add' will configure joins, 'remove' will remove joins
#        mgroup                 first 3 octets of multicast group  (e.g. 232.1.1)
#        mgroup_start           beginning of multicast group range (e.g. 0)
#        mgroup_end             end       of multicast group range (e.g. 255)
#        mgroup_source          IGMPv2 will be used if set to 0.0.0.0
#                               IGMPv3 will be used if set to any valid IPv4 unicast address
#
# -----------------------------------------
# Example EEM configuration (adding IGMPv3)
# -----------------------------------------
# event manager directory user policy flash:/
# event manager env igmp_version 3
# event manager env mgroup_source 10.1.170.10
# event manager env mgroup 232.1.1
# event manager env mgroup_start 0
# event manager env mgroup_end 255
# event manager env igmp_interface vlan90
# event manager env igmp_add_remove add
# event manager policy igmp.tcl
#
# -------------------------
# Example to trigger script
# -------------------------
# Router#event manager run igmp.tcl
#
# -------------------------------------------
# Example EEM configuration (removing IGMPv2)
# -------------------------------------------
# event manager directory user policy flash:/
# event manager env igmp_version 2
# event manager env mgroup 239.1.1
# event manager env mgroup_start 1
# event manager env mgroup_end 254
# event manager env igmp_interface vlan90
# event manager env igmp_add_remove remove
# event manager env mgroup_source 0.0.0.0
# event manager policy igmp.tcl
#
# -------------------------
# Example to trigger script
# -------------------------
# event manager run igmp.tcl
#
# ---------------
# Example syslogs
# ---------------
# (adding igmpv3)
#   %HA_EM-6-LOG: igmp.tcl: Configuring IGMPv3 static joins on loop0
#   %HA_EM-6-LOG: igmp.tcl: Mgroup Source - 10.1.170.10
#   %HA_EM-6-LOG: igmp.tcl: Mgroup Range  - 232.1.1.1  to 232.1.1.254
#   %HA_EM-6-LOG: igmp.tcl: Configuration complete!
#
# (removing igmpv2)
#   %HA_EM-6-LOG: igmp.tcl: Removing IGMPv2 static joins on loop0
#   %HA_EM-6-LOG: igmp.tcl: Mgroup Source - 0.0.0.0
#   %HA_EM-6-LOG: igmp.tcl: Mgroup Range  - 239.1.1.1  to 239.1.1.254
#   %HA_EM-6-LOG: igmp.tcl: Configuration complete!



#---------------- Check for required environment variables -------------


if {![info exists mgroup_start]} {
    set result "EEM Policy Error: variable mgroup_start has not been set"
    error $result $errorInfo
}

if {![info exists mgroup_end]} {
    set result "EEM Policy Error: variable mgroup_end has not been set"
    error $result $errorInfo
}

if {![info exists mgroup_source]} {
    set result "EEM Policy Error: variable mgroup_source has not been set"
    error $result $errorInfo
}

if {![info exists igmp_interface]} {
    set result "EEM Policy Error: variable igmp_interface has not been set"
    error $result $errorInfo
}


#---------------- Namespace imports ---------------

namespace import ::cisco::eem::*
namespace import ::cisco::lib::*


#----------------- Open CLI -------------- 

if [catch {cli_open} result] {
    error $result $errorInfo
} else {
	array set cli1 $result
}

if [catch {cli_exec $cli1(fd) "enable"} result] {
    error $result $errorInfo
}

if [catch {cli_exec $cli1(fd) "config t"} result] {
    error $result $errorInfo
}


if [catch {cli_exec $cli1(fd) "interface $igmp_interface"} result] {
    error $result $errorInfo
}

if { $igmp_version == 2 } {
	if [catch {cli_exec $cli1(fd) "ip igmp version 2"} result] {
    	error $result $errorInfo
	}
}

if { $igmp_version == 3 } {
	if [catch {cli_exec $cli1(fd) "ip igmp version 3"} result] {
    	error $result $errorInfo
	}
}

if { $igmp_add_remove == "add"} {
		action_syslog msg "Configuring IGMPv$igmp_version static joins"
		action_syslog msg "IGMP Interface - $igmp_interface"
		action_syslog msg "Mgroup Source  - $mgroup_source"
		action_syslog msg "Mgroup Range   - $mgroup.$mgroup_start to $mgroup.$mgroup_end"
	for { set i $mgroup_start } { $i <= $mgroup_end} { incr i 1 } {
	#    lappend aList $i
	#    puts [lindex $aList [expr $i - 1]]
		if [catch {cli_exec $cli1(fd) "ip igmp static-group $mgroup.$i source $mgroup_source"} result] {
    		error $result $errorInfo
		}
		if [catch {cli_exec $cli1(fd) "do wr mem"} result] {
    		error $result $errorInfo
		}
	}
} else {
	action_syslog msg "Removing IGMPv$igmp_version static joins"
	action_syslog msg "IGMP Interface - $igmp_interface"
	action_syslog msg "Mgroup Source   - $mgroup_source"
	action_syslog msg "Mgroup Range   - $mgroup.$mgroup_start to $mgroup.$mgroup_end"

	if [catch {cli_exec $cli1(fd) "no ip igmp version $igmp_version"} result] {
	error $result $errorInfo
	}

	for { set i $mgroup_start } { $i <= $mgroup_end} { incr i 1 } {
	#    lappend aList $i
	#    puts [lindex $aList [expr $i - 1]]
		if [catch {cli_exec $cli1(fd) "no ip igmp static-group $mgroup.$i source $mgroup_source"} result] {
    		error $result $errorInfo
		}
		if [catch {cli_exec $cli1(fd) "do wr mem"} result] {
    		error $result $errorInfo
		}
     	}
}

action_syslog msg "Configuration complete!"


# Close cli
 
if [catch {cli_close $cli1(fd) $cli1(tty_id)} result] {
    error $result $errorInfo
}


#----------- end of clock.tcl  --------------------
